// Generated by CoffeeScript 1.8.0
(function() {
  angular.module('ajenti.passwd', ['core']);

}).call(this);

// Generated by CoffeeScript 1.8.0
(function() {
  angular.module('ajenti.passwd').service('passwd', function($http, $q) {
    this.list = function() {
      var q;
      q = $q.defer();
      $http.get("/api/passwd/list").success(function(data) {
        return q.resolve(data);
      }).error(function(err) {
        return q.reject(err);
      });
      return q.promise;
    };
    return this;
  });

}).call(this);

